==> 0.0.7.tar.gz: ios/Classes/MusicMath/Modulo/CompararSimples.swift <==
//
//  CompararSimples.swift
//  Music-Mate-New-Design
//
//  Created by Luis Henrique Marinho Alves on 29/09/18.
//  Copyright © 2018 LT Music Developer. All rights reserved.
//

import Foundation

/**
 * Faz uma comparação de um lista de notas preexistente e response se
 * cada uma das notas é foi tocada(True) ou não(False).
 */
class CompararSimples {
    private let tag = "CompararSimples"
    
    private let taxaDeAmostragem = Configuracoes.ComparadorSimples.taxaAmostragem
    private let comprimentoFourier = Configuracoes.ComparadorSimples.comprimentoFourier
    
    private lazy var analisador = AnalisadorFrequencia(taxaDeAmostragem: taxaDeAmostragem, comprimentoFourier: comprimentoFourier)
  
    func analisar(audio: [Float], engineNote: [Int]) -> [Int] {
        var resultado: [Int]
        
        let group = DispatchGroup()
        group.enter()

        DispatchQueue.global(qos: .background).async {
            let nota = EngineNota(filtro: engineNote[0], inicio: engineNote[1], fim: engineNote[2])
            
            let frequencias = analisador.frequenciasEm(entrada: audio)
            let maisAlto = frequencias.first ?? Pico(index: -1)
            
            switch (maisAlto.filtro - nota.filtro) {
            case _ where Configuracoes.ComparadorSimples.hamonicos.contains(maisAlto.filtro - nota.filtro):
                resultado = [true ? 1 : 0, maisAlto.filtro + 24]
            default:
                if maisAlto.index != -1 {
                    print(maisAlto.filtro, maisAlto.energia)
                    let real = teste(frequencias: frequencias, falso: maisAlto.filtro)
                    if real {
                        resultado = [false ? 1 : 0, maisAlto.filtro + 12]
                    } else {
                        resultado = [false ? 1 : 0, maisAlto.filtro + 24]
                    }
                    
                } else {
                    resultado = [false ? 1 : 0, -1]
                }
            }
            group.leave()
        }
        group.wait()
        
        return resultado
    }
    
    func teste(frequencias: [Pico], falso: Int) -> Bool {
        for pico in frequencias {
            if (falso - 12 == pico.filtro) {
                return true
            }
        }
        
        return false
    }
}

==> 0.0.8.tar.gz: ios/Classes/MusicMath/Modulo/CompararSimples.swift <==
//
//  CompararSimples.swift
//  Music-Mate-New-Design
//
//  Created by Luis Henrique Marinho Alves on 29/09/18.
//  Copyright © 2018 LT Music Developer. All rights reserved.
//

import Foundation

/**
 * Faz uma comparação de um lista de notas preexistente e response se
 * cada uma das notas é foi tocada(True) ou não(False).
 */
class CompararSimples {
    private let tag = "CompararSimples"
    
    private let taxaDeAmostragem = Configuracoes.ComparadorSimples.taxaAmostragem
    private let comprimentoFourier = Configuracoes.ComparadorSimples.comprimentoFourier
    
    private lazy var analisador = AnalisadorFrequencia(taxaDeAmostragem: taxaDeAmostragem, comprimentoFourier: comprimentoFourier)
  
    func analisar(audio: [Float], engineNote: [Int]) -> [Int] {
        var resultado: [Int]
        
        let group = DispatchGroup()
        group.enter()

        DispatchQueue.global(qos: .background).async {
            let nota = EngineNota(filtro: engineNote[0], inicio: engineNote[1], fim: engineNote[2])
            
            let frequencias = self.analisador.frequenciasEm(entrada: audio)
            let maisAlto = frequencias.first ?? Pico(index: -1)
            
            switch (maisAlto.filtro - nota.filtro) {
            case _ where Configuracoes.ComparadorSimples.hamonicos.contains(maisAlto.filtro - nota.filtro):
                resultado = [true ? 1 : 0, maisAlto.filtro + 24]
            default:
                if maisAlto.index != -1 {
                    print(maisAlto.filtro, maisAlto.energia)
                    let real = self.teste(frequencias: frequencias, falso: maisAlto.filtro)
                    if real {
                        resultado = [false ? 1 : 0, maisAlto.filtro + 12]
                    } else {
                        resultado = [false ? 1 : 0, maisAlto.filtro + 24]
                    }
                    
                } else {
                    resultado = [false ? 1 : 0, -1]
                }
            }
            group.leave()
        }
        group.wait()
        
        return resultado
    }
    
    func teste(frequencias: [Pico], falso: Int) -> Bool {
        for pico in frequencias {
            if (falso - 12 == pico.filtro) {
                return true
            }
        }
        
        return false
    }
}
